@@ -30,7 +30,7 @@ template <class ttype>
 Complex L_function <ttype>::
 partial_dirichlet_series(Complex s, long long N1, long long N2)
 {
-    Complex z=0.;
+    Complex z = Double(0);
     long long m,n;
 
     if(what_type_L==-1)   //i.e. if the Riemann zeta function
@@ -50,7 +50,7 @@ template <class ttype>
 Complex L_function <ttype>::
 dirichlet_series(Complex s, long long N)
 {
-    Complex z=0.;
+    Complex z = Double(0);
     long long m,n;
      if(N==-1) N=number_of_dirichlet_coefficients;
     if(N>number_of_dirichlet_coefficients&&what_type_L!=-1&&what_type_L!=1)
@@ -90,7 +90,7 @@ partial_dirichlet_series_via_blfi(Complex s, long long N1, long long N, long lon
 //this function computes sum_{n=N1}^N a_n*n^(-s) in blocks of fixed length K,
 //for testing purposes
 
-    Complex z=0.;
+    Complex z = Double(0);
     long long n;
     long long length_of_remainder_series = (N - N1 + 1) % K;
     long long number_of_blocks = (N - N1 - length_of_remainder_series + 1) / K;
@@ -117,7 +117,7 @@ get_block_value_directly(Complex s, long long v, long long K) {
 // directly, where t=imag(s) and sigma=real(s)
 
     long long m,k;
-    Complex z = 0;
+    Complex z = Double(0);
     Double LG_v_k;
     Double LG_v=LOG(v);
     Double x=-real(s),y=-imag(s);
@@ -294,7 +294,7 @@ dirichlet_series_via_blfi(Complex s, long long N, Double blfi_interval_length, D
 
     }
 
-    Complex z = 0;
+    Complex z = Double(0);
 
     // First, we compute initial sum: sum_{n=1}^v a_n*n^(-s)
     z = partial_dirichlet_series(s, 1, v0);
@@ -338,7 +338,7 @@ dirichlet_series_block_blfi(Complex s, long long v, long long K, int c, int c0,
 
    if(v < 100 || K  < 50) return partial_dirichlet_series(s, v, v + K -1);
 
-   Complex z = 0;
+   Complex z = Double(0);
    Double Pi_over_beta = Pi/beta;
    long long index1 = Long(floor(imag(s)/Pi_over_beta));
    int difference = index1 - index0;
