@@ -4,36 +4,14 @@
 #define Lexplicit_formula_H
 
 
-//#include "Lglobals.h"
-//#include "Lmisc.h"
-
-
 /***************************************************************************************************/
 
-/*
-//// the phi in the explicit formula
-//inline Complex xxx_phi(Double alpha, Double x_0, Complex x)
-inline Complex xxx_phi(Complex x, Double alpha = 1, Double x_0=0, int n=0)
-{
-    return exp(-alpha*(x-x_0)*(x-x_0));
-}
-
-//its fourier transform
-//inline Complex xxx_phi_hat(Double alpha, Double x_0, Complex x)
-inline Complex xxx_phi_hat(Complex x, Double alpha = 1, Double x_0=0, int n=0)
-{
-    return sqrt(Pi/alpha) * exp(-2*Pi*I*x_0*x - Pi*Pi*x*x/alpha);
-}
-
-*/
-
-
 template <class ttype>
 inline ttype hermite_H(ttype y,int n=0){
-    if(n==0) return 1;
+    if(n==0) return Double(1);
     else if(n==1) return 2*y;
     else{
-        ttype H_a = 1, H_b = 2*y, H_c;
+        ttype H_a = Double(1), H_b = 2*y, H_c;
         int count = 1;
         do{
             H_c= 2*(y*H_b-count*H_a);
@@ -59,7 +37,8 @@ template <class ttype>
 ttype xxx_phi(ttype x, Double alpha = Double(1), Double x_0=Double(0), const char *method="hermite", int n=0,vector<Double> polynomial=vector<Double>())
 {
 
-    ttype phi;
+    ttype phi = Double(0);
+
     //nth hermite function, scaled
     if(!strcmp(method,"hermite")){
         ttype y=(x-x_0)*sqrt(2*alpha);  //center on x_0 and scale by alpha. Because of the y*y/2 we use sqrt(2*alpha) so as to get a factor of exp(-alpha(x-x_0)^2)
@@ -94,8 +73,6 @@ ttype xxx_phi(ttype x, Double alpha = Double(1), Double x_0=Double(0), const cha
         3780.0*alpha*alpha*alpha*pow_log7_2-50400.0*alpha*alpha*alpha*alpha*alpha*alpha*y*y*y*
         y-30240.0*alpha*alpha*alpha*alpha*y*y*pow_log7_2-1575.0*alpha*alpha*pow_log7_4+20160.0*alpha*alpha*alpha*alpha*alpha*alpha*alpha*y*y*y*y*y*y+9450.0*alpha*alpha*alpha*
         y*y*pow_log7_4+30240.0*alpha*alpha*alpha*alpha*alpha*y*y*y*y*pow_log7_2+348.0*alpha*pow_log7_6)/sqrt(pow_pi_21)/128.0;
-        //phi:=simplify(int(exp(-Pi^2*u*u/alpha)*exp(2*Pi*I*u*x)*u*u*(u+log(7)/(2*Pi))*(u-log(7)/(2*Pi))*(u-2*log(7)/(2*Pi)
-        //*(u+2*log(7)/(2*Pi))*(u-2*log(7)/(2*Pi))*(u+2*log(7)/(2*Pi))*(u-3*log(7)/(2*Pi))*(u+3*log(7)/(2*Pi)),u=-infinity..infinity));
 
         ttype phi_of_0=-exp(0.0)*sqrt(alpha*alpha*alpha)*(-3780.0*alpha*alpha*alpha*alpha-36.0*pow_log7_8+3780.0*alpha*alpha*alpha*pow_log7_2-1575.0*alpha*alpha*pow_log7_4
         +348.0*alpha*pow_log7_6)/sqrt(pow_pi_21)/128.0;
@@ -143,12 +120,10 @@ inline Complex xxx_phi_hat(Double u, Double alpha = Double(1), Double x_0=Double
         for(int j = 1;j<=n-1;j++) r2*=2*j;
         r2=Pi/r2;
 
-        //vector<Double>::size_type deg=polynomial.size()-1;
         int deg=int(polynomial.size()-1);
 
         Complex s=Double(0);
 
-        //for(vector<Double>::size_type i=0;i<=deg;i++){
         for(int i=0;i<=deg;i++){
             Complex I_factor;
             switch(i%4){
@@ -168,7 +143,6 @@ inline Complex xxx_phi_hat(Double u, Double alpha = Double(1), Double x_0=Double
             r=r2*I_factor*polynomial[i];
             for(int j=0;j<=n;j++){
                 s+=r*pow(w+n-2*j,n-1-i)*Heaviside(w+n-2*j);
-                //cout << "            sinc_hat sum: " << j << " " << pow(w+n-2*j,n-1)*Heaviside(w+n-2*j)  << " :r: " << r << " " << n-j << endl;
                 r=-(n-j)*r/(j+1);
             }
             r2*=(n-i-1);
@@ -186,48 +160,12 @@ inline Complex xxx_phi_hat(Double u, Double alpha = Double(1), Double x_0=Double
         Double s=Double(0);
         for(int j=0;j<=n;j++){
             s+=r*pow(w+n-2*j,n-1)*Heaviside(w+n-2*j);
-//cout << "            sinc_hat sum: " << j << " " << pow(w+n-2*j,n-1)*Heaviside(w+n-2*j)  << " :r: " << r << " " << n-j << endl;
             r=-(n-j)*r/(j+1);
         }
         phi_hat=s*lcalc_expIt(-twoPi*x_0*u)/alpha;
     }
 
     else if(!strcmp(method,"alice")){
-        /*
-        Double w=twoPi*u/alpha;
-        Double r=Double(1);
-        for(int j = 1;j<=n-1;j++) r*=2*j;
-        r=Pi/r;
-        Double s=Double(0);
-        for(int j=0;j<=n;j++){
-            s+=r*pow(w+n-2*j,n-1)*Heaviside(w+n-2*j);
-//cout << "            sinc_hat sum: " << j << " " << pow(w+n-2*j,n-1)*Heaviside(w+n-2*j)  << " :r: " << r << " " << n-j << endl;
-            r=-(n-j)*r/(j+1);
-        }
-        phi_hat=I*w*(u-log(7.)/(twoPi))*(u+log(7.)/(twoPi))*s*lcalc_expIt(-twoPi*x_0*u)/alpha;
-        */
-
-        /*
-        Double y=twoPi*u/sqrt(2*alpha);
-        Double phi_0= hermite_norm[n]*hermite_H(y,n)*exp(-y*y/2);
-
-        Complex I_factor;
-        switch(n%4){
-            case 0:
-                I_factor=1;
-                break;
-            case 1:
-                I_factor=-I;
-                break;
-            case 2:
-                I_factor=-1;
-                break;
-            case 3:
-                I_factor=-I;
-                break;
-        }
-        phi_hat=I_factor*sqrt(Pi/alpha)*phi_0*lcalc_expIt(-twoPi*x_0*u)*(u-log(7.)/(twoPi))*(u+log(7.)/(twoPi))*(u-2*log(7.)/(twoPi))*(u+2*log(7.)/(twoPi));
-       */
        Double pow_log7_2 = pow((Double)log(7.0),2.0);
        Double pow_log7_4 = pow((Double)log(7.0),4.0);
        Double pow_log7_6 = pow((Double)log(7.0),6.0);
@@ -246,9 +184,6 @@ inline Complex xxx_phi_hat(Double u, Double alpha = Double(1), Double x_0=Double
 
        phi_hat=phi_hat/phi_of_0;
 
-       //phi_hat is simplify((exp(-Pi^2*u*u/alpha)*u*u*(u+log(7)/(2*Pi))*(u-log(7)/(2*Pi))*(u-2*log(7)/(2*Pi))*(u+2*log(7)/(2*Pi))
-       //*(u-2*log(7)/(2*Pi))*(u+2*log(7)/(2*Pi))*(u-3*log(7)/(2*Pi))*(u+3*log(7)/(2*Pi)))); TIMES lcalc_expIt(-twoPi*x_0*u)
-
     }
 
 
@@ -356,28 +291,8 @@ dirichlet_coeffs_log_diff(int num_coeffs, Complex *c)
               temp = dirichlet_coefficient[d1]*b[j];
           total -= temp;
           total2 += temp*LOG(d1);
-          //cout << j << " : " << n << endl;
           j*=p;
        }while(j<n);
-      /*
-      for (j=1;j<=n/2;j++) if (n % j == 0)
-      {
-          d1 = n/j;
-          if (what_type_L == -1)
-              temp = b[j];
-          else if (what_type_L == 1)
-          {
-            ind = d1 % period;
-            if (ind == 0)
-                ind = period;
-            temp = dirichlet_coefficient[ind]*b[j];
-          }
-          else
-              temp = dirichlet_coefficient[d1]*b[j];
-          total -= temp;
-          total2 += temp*LOG(d1);
-        }
-       */
        b[n] = total;
        c[n] = total2;
        if(my_verbose>4) cout << "                c[" << n << "] = " << c[n] << endl;
@@ -419,7 +334,6 @@ test_explicit_formula(Double x_0, Double alpha, Double *zero_table, int number_z
     u=u*u*alpha;
     if(u<2.3*DIGITS+2){
         LHS += real(xxx_phi(zero_table[j],alpha,x_0,method,n,polynomial));
-        //cout << "LHS, u: " << u << " , contribution: " << exp(-u) << endl;
     }
   }
 
@@ -479,23 +393,15 @@ rhs_explicit_formula(Double x_0, Double alpha, Complex *c, int num_coeffs, const
   int p, m, x, j;
   Double temp;
   Double RHS;
-  //Complex *c;
-  //int num_coeffs;
-
-  //num_coeffs = 150; //XXXXXXXXXX should depend on test required
-  //c = new Complex[num_coeffs+1]; //XXXXXXX move to L.h
-  //dirichlet_coeffs_log_diff(num_coeffs, c);
 
   //compute the possible contribution from poles
 
   term1 = 0.;
   for (j=1;j<=number_of_poles;j++){
     term1 += real(xxx_phi((pole[j]-0.5)/I,alpha,x_0,method,n,polynomial));
-    //cout << "pole: " << (pole[j]-.5)/I << " XXXXXX  term1: " << term1 << endl;
   }
   // compute the contribution from the Gamma factors (integral of the log diff)
 
-  //t_step = .25*Pi/sqrt(2.3*DIGITS*alpha); //bogus formula
   t_step = .01;
 
 
@@ -521,13 +427,11 @@ rhs_explicit_formula(Double x_0, Double alpha, Complex *c, int num_coeffs, const
         for (j=1;j<=this->a;j++)
         {
           temp +=  2*real(log_GAMMA(gamma[j]/2 + I*t*gamma[j]+lambda[j], 1)*gamma[j]); //'1' tells log_GAMMA to compute the logarithmic derivative
-          //temp +=  log_GAMMA(gamma[j]/2 - I*t*gamma[j]+conj(lambda[j]), 1)*gamma[j];
         }
 
 
         total = total + real(xxx_phi(t,alpha, x_0, method,n,polynomial)) * temp; //xxx_phi in this line is real, but the value is returned as a Complex,
                                                      //so we take it's real part since total is a Double
-        //cout << t << "term2 " << total*t_step << endl;
       }
   }
 
@@ -542,11 +446,9 @@ rhs_explicit_formula(Double x_0, Double alpha, Complex *c, int num_coeffs, const
         for (j=1;j<=this->a;j++)
         {
           temp +=  2*real(log_GAMMA(gamma[j]/2 + I*t*gamma[j]+lambda[j], 1)*gamma[j]); //'1' tells log_GAMMA to compute the logarithmic derivative
-          //temp +=  log_GAMMA(gamma[j]/2 - I*t*gamma[j]+conj(lambda[j]), 1)*gamma[j];
         }
         total = total + real(xxx_phi(t,alpha, x_0, method,n,polynomial)) * temp * cosh(sinh_tm) * cosh(t_step*m); //xxx_phi in this line is real, but the value is returned as a Complex,
                                                                                                      //so we take it's real part since total is a Double
-        //cout << t << "term2 " << total*t_step << endl;
       }
   }
 
@@ -569,9 +471,7 @@ rhs_explicit_formula(Double x_0, Double alpha, Complex *c, int num_coeffs, const
     do
     {
       m *= p;
-      //temp = 2*real(c[m]*xxx_phi_hat(alpha, x_0, LOG(m)/(2*Pi)));// + conj(c[m])*xxx_phi_hat(alpha, x_0, -LOG(m)/(2*Pi));
-      temp = 2*real(c[m]*xxx_phi_hat(LOG(m)/(2*Pi),alpha,x_0,method,n,polynomial));// + conj(c[m])*xxx_phi_hat(alpha, x_0, -LOG(m)/(2*Pi));
-      //cout << m << "           alice phi_hat: " << xxx_phi_hat(LOG(m)/(2*Pi),alpha,x_0,method,n) << endl;
+      temp = 2*real(c[m]*xxx_phi_hat(LOG(m)/(2*Pi),alpha,x_0,method,n,polynomial));
       term3 += two_inverse_sqrt(m)*temp;
     }while(double(m)*p <= x);
     j++;
@@ -615,10 +515,6 @@ plot_explicit_formula(Double alpha, Double x, Double x2, Double step_size, const
         << xxx_phi_method << " "
         << num_coeffs << endl;
 
-    //cout <<"#   STEPSIZE = " << step_size << endl;
-    //cout <<"#   x = " << x << endl;
-    //cout <<"#   x2 = " << x2 << endl;
-
     int number_of_log_diff_coeff;
     int n=0; // as in hermite_n, or sinc_n = sin(alpha x)^n/(alpha x)^n. hermite_0 is const exp(-alpha x^2).
 
@@ -627,16 +523,11 @@ plot_explicit_formula(Double alpha, Double x, Double x2, Double step_size, const
     // ========  parse the xxx_phi_method string to determine which method to use  ===========
     //========================================================================================
 
-    //const char *ptr = xxx_phi_method;
     char method[100];
     vector<Double> polynomial;
 
     vector<string> method_parsed = split(xxx_phi_method, '_');
 
-    //if(my_verbose>4) for(vector<string>::size_type j = 0; j != method_parsed.size(); j++) {
-    //    cout << "#                    explicit formula method, parsed: " << method_parsed[j] << endl;
-    //}
-
     strcpy(method,method_parsed[0].c_str());
     if(method_parsed.size()>1) n=atoi(method_parsed[1].c_str());
     if(my_verbose>0) cout << "#    plot explicit formula, phi method = "<< method << "_" << n << endl;
@@ -656,16 +547,14 @@ plot_explicit_formula(Double alpha, Double x, Double x2, Double step_size, const
     // ========  decide how many terms of the Dirichlet series of L'/L to use  ===============
     //========================================================================================
 
-    double N_as_double; //as double because we might exceed INT_MAX
+    double N_as_double = 0; //as double because we might exceed INT_MAX
     if(!strcmp(method,"hermite")){
         N_as_double = lcalc_to_double(exp(sqrt(2.3*DIGITS*4*alpha)));
         if(my_verbose>0) cout << "#    plot explicit formula, N_as_double = " << N_as_double << endl;
     }
 
-    //if(!strcmp(method,"sinc")||!strcmp(method,"alice")){
     if(!strcmp(method,"sinc")){
         N_as_double = lcalc_to_double(exp(n*alpha));
-        //if(my_verbose>1) cout << "#        plot explicit formula, N_as_double = " << N_as_double << endl;
     }
 
     if(!strcmp(method,"alice")){
@@ -689,16 +578,13 @@ plot_explicit_formula(Double alpha, Double x, Double x2, Double step_size, const
         cout << "# WARNING Will use p^k < 100000000" << endl;
         number_of_log_diff_coeff=100000000; //for zeta or Dirichlet L-functions I've set the max number of terms at 1000000
         Double tmp= log(Double(number_of_log_diff_coeff))/(twoPi);
-        //cout << "These can only give compute the rhs of the explicit formula to within: " << exp(-Pi*Pi/alpha*tmp*tmp) << endl;
-        //cout << "#tmp: " << tmp;
-        //cout << "#alpha: " << alpha;
+
         //XXXXXXXXXXXXXXX  needs to be fixed to take into account the slow rate of decay of the prime power sum, i.e one term does not dominate the tail
         cout << "# WARNING These can only give the rhs of the explicit formula to within roughly: " << abs(xxx_phi_hat(tmp,alpha,Double(0),method,n,polynomial)) << endl;
 
     }
 
     else number_of_log_diff_coeff=Int(N_as_double);
-    //else number_of_log_diff_coeff=Int(exp(sqrt(2.3*DIGITS*4*alpha)));
 
     if(my_verbose>1){
         cout << "#        plot_explicit_formula called with: alpha = "<< alpha << ", " << x << " <= x0 <= " << x2 << endl;
@@ -731,7 +617,6 @@ plot_explicit_formula(Double alpha, Double x, Double x2, Double step_size, const
 
         if(rhs_store){
             rhs_store[count]=rhs;
-            //cout << method<< "_" << n << " ::::::::: " << t << " " << rhs_store[count] << endl;
             count++;
             t+=step_size;
         }
@@ -745,7 +630,6 @@ plot_explicit_formula(Double alpha, Double x, Double x2, Double step_size, const
     }while(t<=x2);
 
 
-    //delete [] rhs_store;
     delete [] xxx_log_diff_coeffs;
     return 0;
 }
